@@ -1,4 +1,10 @@
 #!/bin/bash
+# Copyright (C) 2018-2021 Intel Corporation
+# SPDX-License-Identifier: Apache-2.0
+
+#Checking OS_VERSION
+
+echo "Checking OS_VERSION"
 
 OS_VERSION=$( . /etc/os-release ; echo $VERSION_ID)
 echo "System OS : $OS_VERSION"
@@ -10,6 +16,10 @@ if [[ $OS_VERSION != "18.04" ]]; then
 
 fi
 
+#Installing Proxy settings for Openvino
+
+echo "Installing Proxy settings for Openvino"
+
 sudo chmod 777 /etc/environment
 sudo echo "http_proxy=http://proxy-dmz.intel.com:911
 https_proxy=http://proxy-dmz.intel.com:911
@@ -21,8 +31,17 @@ NO_PROXY=localhost,127.0.0.1
 source /etc/environment
 export no_proxy="localhost,127.0.0.1"
 
-
+#Installing intelligent-traffic-management
 
 echo "Installing intelligent-traffic-management ..."
-pip3 install --upgrade pip --user && pip3 install edgesoftware --user
+
+sudo pip3 install --upgrade pip --user && sudo pip3 install edgesoftware --user
 echo ad655e14-66bb-479f-9343-482f0b62e000 | $HOME/.local/bin/edgesoftware install intelligent-traffic-management 61710291d8ecccee551c9463
+
+echo -e "\e[1;34mIntelligent_Traffic_Management_<version> folder is downloaded in \home\intel\<username>\e[0m\n"
+
+#Check RI is installed sucessfully
+
+echo -e "\e[1;32m\nIf RI installed suceessfully...\e[0m"
+echo -e "\e[1;36mFor further development refer below URL\e[0m"
+echo -e "\e[1;33mhttps://www.intel.com/content/www/us/en/developer/articles/reference-implementation/intelligent-traffic-management.html\e[0m\n"
